These functions are defunct and their symbols will be removed entirely in a future release.
Arguments
- lsting
listing_df. The listing to paginate.
- lpp
numeric(1) or NULL. Number of row lines (not counting titles and footers) to have per page. Standard is
70whileNULLdisables vertical pagination.- colwidths
numeric vector. Column widths (in characters) for use with vertical pagination.
- max_width
integer(1), character(1) or
NULL. Width that title and footer (including footnotes) materials should be word-wrapped to. IfNULL, it is set to the current print width of the session (getOption("width")). If set to"auto", the width of the table (plus any table inset) is used. Ignored completely iftf_wrapisFALSE.- verbose
logical(1). Should additional informative messages about the search for pagination breaks be shown. Defaults to
FALSE.